@@ -1,5 +1,16 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 
+#define _JENT_AC(X,Y)   (X##Y)
+#define JENT_AC(X,Y)            _JENT_AC(X,Y)
+
+#define JENT_UL(x)              (JENT_AC(x, UL))
+#define JENT_ULL(x)             (JENT_AC(x, ULL))
+
+#define JENT_BIT(nr)            (JENT_UL(1) << (nr))
+#define JENT_BIT_ULL(nr)        (JENT_ULL(1) << (nr))
+
+#define JENT_CONF_DISABLE_LOOP_SHUFFLE
+
 extern void jent_get_nstime(__u64 *out);
 extern int jent_hash_time(void *hash_state, __u64 time, u8 *addtl,
 			  unsigned int addtl_len, __u64 hash_loop_cnt,
